[Bf-blender-cvs] SVN commit: /data/svn/bf-blender [44193] trunk/blender/source/blender/ editors/animation/keyframing.c: Minor fixes found while working on keyingsets.

Bastien Montagne montagne29 at wanadoo.fr
Fri Feb 17 17:34:33 CET 2012


Revision: 44193
          http://projects.blender.org/scm/viewvc.php?view=rev&root=bf-blender&revision=44193
Author:   mont29
Date:     2012-02-17 16:34:28 +0000 (Fri, 17 Feb 2012)
Log Message:
-----------
Minor fixes found while working on keyingsets.

Modified Paths:
--------------
    trunk/blender/source/blender/editors/animation/keyframing.c

Modified: trunk/blender/source/blender/editors/animation/keyframing.c
===================================================================
--- trunk/blender/source/blender/editors/animation/keyframing.c	2012-02-17 16:06:32 UTC (rev 44192)
+++ trunk/blender/source/blender/editors/animation/keyframing.c	2012-02-17 16:34:28 UTC (rev 44193)
@@ -1178,7 +1178,8 @@
 	/* confirm whether a keyframe was added by showing a popup 
 	 *	- by default, this is enabled, since this operator is assumed to be called independently
 	 */
-	prop= RNA_def_boolean(ot->srna, "confirm_success", 1, "Confirm Successful Insert", "Show a popup when the keyframes get successfully added");
+	prop= RNA_def_boolean(ot->srna, "confirm_success", 1, "Confirm Successful Insert",
+	                      "Show a popup when the keyframes get successfully added");
 	RNA_def_property_flag(prop, PROP_HIDDEN);
 }
 
@@ -1233,7 +1234,8 @@
 	 *	- by default, this is disabled so that if a menu is shown, this doesn't come up too
 	 */
 	// XXX should this just be always on?
-	prop= RNA_def_boolean(ot->srna, "confirm_success", 0, "Confirm Successful Insert", "Show a popup when the keyframes get successfully added");
+	prop= RNA_def_boolean(ot->srna, "confirm_success", 0, "Confirm Successful Insert",
+	                      "Show a popup when the keyframes get successfully added");
 	RNA_def_property_flag(prop, PROP_HIDDEN);
 	
 	/* whether the menu should always be shown 
@@ -1273,7 +1275,7 @@
 		return OPERATOR_CANCELLED;
 	}
 	
 	/* try to insert keyframes for the channels specified by KeyingSet */
 	success= ANIM_apply_keyingset(C, NULL, NULL, ks, MODIFYKEY_MODE_DELETE, cfra);
 	if (G.f & G_DEBUG)
 		printf("KeyingSet '%s' - Successfully removed %d Keyframes \n", ks->name, success);
@@ -1325,7 +1327,8 @@
 	/* confirm whether a keyframe was added by showing a popup 
 	 *	- by default, this is enabled, since this operator is assumed to be called independently
 	 */
-	RNA_def_boolean(ot->srna, "confirm_success", 1, "Confirm Successful Insert", "Show a popup when the keyframes get successfully added");
+	RNA_def_boolean(ot->srna, "confirm_success", 1, "Confirm Successful Delete",
+	                "Show a popup when the keyframes get successfully removed");
 }
 
 /* Delete Key Operator ------------------------ */
@@ -1273,7 +1275,7 @@
 	}
 	
-	/* try to insert keyframes for the channels specified by KeyingSet */
+	/* try to delete keyframes for the channels specified by KeyingSet */
 	success= ANIM_apply_keyingset(C, NULL, NULL, ks, MODIFYKEY_MODE_DELETE, cfra);
 	if (G.f & G_DEBUG)




More information about the Bf-blender-cvs mailing list